from mlfoundry.frameworks.fastai_registry import FastAIRegistry
from mlfoundry.frameworks.gluon_registry import GluonRegistry
from mlfoundry.frameworks.h2o_registry import H2ORegistry
from mlfoundry.frameworks.keras_registry import KerasRegistry
from mlfoundry.frameworks.lightgbm_registry import LightGBMRegistry
from mlfoundry.frameworks.onnx_registry import ONNXRegistry
from mlfoundry.frameworks.paddle_registry import PaddleRegistry
from mlfoundry.frameworks.pytorch_registry import PyTorchRegistry
from mlfoundry.frameworks.sklearn_registry import SkLearnRegistry
from mlfoundry.frameworks.spacy_registry import SpacyRegistry
from mlfoundry.frameworks.statsmodel_registry import StatsModelsRegistry
from mlfoundry.frameworks.tensorflow_registry import TensorflowRegistry
from mlfoundry.frameworks.xgboost_registry import XGBoostRegistry
